Alignment class

Describes a character's alignment.

Mixed-in types

Constructors

Alignment({required dynamic meta, required AlignmentType type, required String description})
Alignment.fromJson(Map<String, dynamic> json)
factory
Alignment.fromRawJson(String str)
factory

Properties

debugProperties → String
no setter
description → String
The alignment's description
final
displayName → String
This entity's display name, as the user would see it
no setteroverride
hashCode → int
The hash code for this object.
no setteroverride
key → String
This entity's unique key
no setteroverride
meta → dynamic
Dynamic metadata
final
reference → EntityReference
Get a reference to this entity, which can be used to look it up in a repository.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → AlignmentType
The alignment being described
final

Methods

copyWith({AlignmentType? type, String? description}) → Alignment
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toRawJson() → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override