AlignmentValues class

Describes the alignment values available in Dungeon World, and their respective descriptions.

Constructors

AlignmentValues({required String good, required String evil, required String lawful, required String neutral, required String chaotic})
AlignmentValues.fromJson(Map<String, dynamic> json)
factory
AlignmentValues.fromRawJson(String str)
factory

Properties

chaotic → String
The description of the chaotic alignment
final
debugProperties → String
no setter
evil → String
The description of the evil alignment
final
good → String
The description of the good alignment
final
hashCode → int
The hash code for this object.
no setteroverride
lawful → String
The description of the lawful alignment
final
neutral → String
The description of the neutral alignment
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? good, String? evil, String? lawful, String? neutral, String? chaotic}) → AlignmentValues
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toRawJson() → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override