KeyMixin mixin

This mixin ensures a key and a display name for an entity.

Mixin applications

Properties

displayName → String
This entity's display name, as the user would see it
no setter
hashCode → int
The hash code for this object.
no setterinherited
key → String
This entity's unique key
final
reference → EntityReference
Get a reference to this entity, which can be used to look it up in a repository.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited