CharacterClass class

Describes a Dungeon World character class

Mixed-in types

Constructors

CharacterClass({required dynamic meta, required String name, required String key, required String description, required Dice damageDice, required int load, required int hp, required AlignmentValues alignments, required List<String> bonds, required List<String> flags, required List<GearChoice> gearChoices, required bool isSpellcaster})
CharacterClass.fromJson(Map<String, dynamic> json)
factory
CharacterClass.fromRawJson(String str)
factory

Properties

alignments → AlignmentValues
This class's set of alignments along with their descriptions
final
bonds → List<String>
This class's default bonds
final
damageDice → Dice
Dice used for damage calculation
final
debugProperties → String
no setter
description → String
Class description
final
displayName → String
This entity's display name, as the user would see it
no setteroverride
flags → List<String>
This class's default flags
final
gearChoices → List<GearChoice>
This class's starting gear options
final
hashCode → int
The hash code for this object.
no setteroverride
hp → int
CLass's base HP, which is added to the character's CON modifier to calculate Max HP
final
isSpellcaster → bool
Whether this class is a Magic User, and therefore has access to spells
final
key → String
This entity's unique key
final
load → int
CLass's base load, which is added to the character's STR modifier to calculate Max Load
final
meta → dynamic
Dynamic metadata
final
name → String
Class name, such as 'Wizard', 'Paladin'
final
reference → EntityReference
Get a reference to this entity, which can be used to look it up in a repository.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({dynamic meta, String? name, String? key, String? description, Dice? damageDice, int? load, int? hp, AlignmentValues? alignments, List<String>? bonds, List<String>? flags, List<GearChoice>? gearChoices, bool? isSpellcaster}) → CharacterClass
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toRawJson() → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override