EntityReference class

A reference to an entity. This is useful for storing the name & key of an entity without having to store the entire entity, possibly for use in a dropdown or other UI element, or linking between entities in a database.

Constructors

EntityReference({required String key, required String name, required String type})
EntityReference.fromJson(Map<String, dynamic> json)
factory
EntityReference.fromRawJson(String str)
factory

Properties

debugProperties → String
no setter
hashCode → int
The hash code for this object.
no setteroverride
key → String
The key of the entity.
final
name → String
The name of the entity.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
The type of the entity.
final

Methods

copyWith({String? key, String? name, String? type}) → EntityReference
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toRawJson() → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object? other) → bool
The equality operator.
override