GearSelection class

One possible selection of many, which is a "bundle" of items and coins. Contains multiple options, each of which is an item and amount, and total coins.

All of these should be added at once when making a selection. This is the final level of selection, the inner options are all given to the player.

Mixed-in types

Constructors

GearSelection({required String key, required String description, required List<GearOption> options, required double coins})
GearSelection.fromJson(Map<String, dynamic> json)
factory
GearSelection.fromRawJson(String str)
factory

Properties

coins → double
The number of coins to receive.
final
debugProperties → String
no setter
description → String
The description of the gear selection. For example, "Your father's sword and 60 coins.".
final
displayName → String
This entity's display name, as the user would see it
no setteroverride
hashCode → int
The hash code for this object.
no setteroverride
key → String
This entity's unique key
final
options → List<GearOption>
The list of options contained in this selection.
final
reference → EntityReference
Get a reference to this entity, which can be used to look it up in a repository.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? key, String? description, List<GearOption>? options, double? coins}) → GearSelection
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toRawJson() → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override