Item class

Represents an item: a potion, weapon, armor, etc. Contains a name, description, and tags.

Mixed-in types

Constructors

Item({required dynamic meta, required String key, required String description, required String name, required List<Tag> tags})
Item.fromJson(Map<String, dynamic> json)
factory
Item.fromRawJson(String str)
factory

Properties

debugProperties → String
no setter
description → String
The description of the item.
final
displayName → String
This entity's display name, as the user would see it
no setteroverride
hashCode → int
The hash code for this object.
no setteroverride
key → String
This entity's unique key
final
meta → dynamic
Dynamic metadata
final
name → String
The name of the item.
final
reference → EntityReference
Get a reference to this entity, which can be used to look it up in a repository.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<Tag>
The tags of the item.
final

Methods

copyWith({dynamic meta, String? key, String? name, String? description, List<Tag>? tags}) → Item
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toRawJson() → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override