Monster class

Represents a monster.

Mixed-in types

Constructors

Monster({required dynamic meta, required String key, required String name, required String description, required String instinct, required List<Tag> tags, required List<String> moves})
Monster.fromJson(Map<String, dynamic> json)
factory
Monster.fromRawJson(String str)
factory

Properties

debugProperties → String
no setter
description → String
The description of the monster.
final
displayName → String
This entity's display name, as the user would see it
no setteroverride
hashCode → int
The hash code for this object.
no setteroverride
instinct → String
The instinct of the monster.
final
key → String
This entity's unique key
final
meta → dynamic
final
moves → List<String>
The moves of the monster.
final
name → String
The name of the monster.
final
reference → EntityReference
Get a reference to this entity, which can be used to look it up in a repository.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<Tag>
The tags of the monster.
final

Methods

copyWith({dynamic meta, String? key, String? name, String? description, String? instinct, List<Tag>? tags, List<String>? moves}) → Monster
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toRawJson() → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object? other) → bool
The equality operator.
override