Move class

Mixed-in types

Constructors

Move({required dynamic meta, required String key, required String name, required String description, required String explanation, required List<Dice> dice, required List<EntityReference> classKeys, required List<Tag> tags, required MoveCategory category})
Move.fromJson(Map<String, dynamic> json)
factory
Move.fromRawJson(String str)
factory

Properties

category → MoveCategory
The category of the move
final
classKeys → List<EntityReference>
The class keys of the move - which classes can take this move.
final
debugProperties → String
no setter
description → String
The description of the move - what it does, and how it works mechanically.
final
dice → List<Dice>
The dice of the move - how many dice to roll, and what size.
final
displayName → String
This entity's display name, as the user would see it
no setteroverride
explanation → String
The explanation of the move - how it works in the fiction, examples or other details.
final
hashCode → int
The hash code for this object.
no setteroverride
key → String
This entity's unique key
final
meta → dynamic
final
name → String
The name of the move.
final
reference → EntityReference
Get a reference to this entity, which can be used to look it up in a repository.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<Tag>
The tags of the move
final

Methods

copyWith({dynamic meta, String? key, String? name, String? description, String? explanation, List<Dice>? dice, List<EntityReference>? classKeys, List<Tag>? tags, MoveCategory? category}) → Move
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toRawJson() → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override