Race class

Represents a playable race such as a human, elf, or dwarf.

Mixed-in types

Constructors

Race({required dynamic meta, required String key, required String name, required String description, required String explanation, required List<Dice> dice, required List<EntityReference> classKeys, required List<Tag> tags})
Race.fromJson(Map<String, dynamic> json)
factory
Race.fromRawJson(String str)
factory

Properties

classKeys → List<EntityReference>
Classes that can be assigned to this race
final
debugProperties → String
no setter
description → String
The description of the race's unique move. Contains what it does, and how it works mechanically.
final
dice → List<Dice>
The dice list rolled when using this race's unique move.
final
displayName → String
This entity's display name, as the user would see it
no setteroverride
explanation → String
The explanation of the race's unique move - how it works in the fiction, examples or other details.
final
hashCode → int
The hash code for this object.
no setteroverride
key → String
This entity's unique key
final
meta → dynamic
final
name → String
The name of the race
final
reference → EntityReference
Get a reference to this entity, which can be used to look it up in a repository.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<Tag>
The tags of this race
final

Methods

copyWith({dynamic meta, String? key, String? name, String? description, String? explanation, List<EntityReference>? classKeys, List<Tag>? tags, List<Dice>? dice}) → Race
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toRawJson() → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override