SessionMark class

Mixed-in types

Constructors

SessionMark({required String key, required String description, required bool completed, required SessionMarkType type})
SessionMark.fromJson(Map<String, dynamic> json)
factory
SessionMark.fromRawJson(String str)
factory

Properties

completed → bool
Whether or not the session mark has been completed, or checked.
final
debugProperties → String
no setter
description → String
The description of the session mark. When to mark it, what it means, etc.
final
displayName → String
This entity's display name, as the user would see it
no setteroverride
hashCode → int
The hash code for this object.
no setteroverride
key → String
This entity's unique key
final
reference → EntityReference
Get a reference to this entity, which can be used to look it up in a repository.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → SessionMarkType
The type of session mark.
final

Methods

copyWith({String? key, String? description, bool? completed, SessionMarkType? type}) → SessionMark
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toRawJson() → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override