Spell class

Represents a spell, or spell-like ability.

Mixed-in types

Constructors

Spell({required dynamic meta, required String key, required String name, required String description, required String explanation, required String level, required List<EntityReference> classKeys, required List<Dice> dice, required List<Tag> tags})
Spell.fromJson(Map<String, dynamic> json)
factory
Spell.fromRawJson(String str)
factory

Properties

classKeys → List<EntityReference>
Classes that can use this spell
final
debugProperties → String
no setter
description → String
The description of the spell's effect, and how it works mechanically.
final
dice → List<Dice>
The dice list rolled when using this spell.
final
displayName → String
This entity's display name, as the user would see it
no setteroverride
explanation → String
The explanation of the spell's effect - how it works in the fiction, examples or other details.
final
hashCode → int
The hash code for this object.
no setteroverride
key → String
This entity's unique key
final
level → String
The level of the spell
final
meta → dynamic
final
name → String
The name of the spell
final
reference → EntityReference
Get a reference to this entity, which can be used to look it up in a repository.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<Tag>
The tags of this spell
final

Methods

copyWith({dynamic meta, String? key, String? name, String? description, String? explanation, String? level, List<EntityReference>? classKeys, List<Dice>? dice, List<Tag>? tags}) → Spell
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toRawJson() → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object? other) → bool
The equality operator.
override