Tag class

Represents a tag. Contains a name, value, and description. Examples are weight: 1, damage: 1d6, etc.

Mixed-in types

Constructors

Tag({required String name, required dynamic value, String description = ""})
Tag.fromJson(Map<String, dynamic> json)
factory
Tag.fromRawJson(String str)
factory

Properties

debugProperties → String
no setter
description → String
The description of the tag.
final
displayName → String
This entity's display name, as the user would see it
no setteroverride
hashCode → int
The hash code for this object.
no setteroverride
key → String
This entity's unique key
no setteroverride
name → String
The name of the tag.
final
reference → EntityReference
Get a reference to this entity, which can be used to look it up in a repository.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → dynamic
The value of the tag.
final

Methods

copyWith({String? name, dynamic value, String? description}) → Tag
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toRawJson() → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override